/* eslint-env node */

module.exports = {
	plugins: ['simple-import-sort', 'import'],
	extends: ['eslint:recommended'],
	env: {
		es6: true,
		browser: true,
	},
	reportUnusedDisableDirectives: true,
	parser: '@babel/eslint-parser',
	parserOptions: {
		ecmaFeatures: {
			jsx: true,
		},
		sourceType: 'module',
		requireConfigFile: false,
	},
	rules: {
		'no-template-curly-in-string': 'error',
		'array-callback-return': 'error',
		'arrow-body-style': ['error', 'as-needed'],
		'arrow-spacing': ['error', { before: true, after: true }],
		'consistent-return': 'error',
		curly: 'warn',
		'default-param-last': 'error',
		eqeqeq: ['error', 'always', { null: 'ignore' }],
		'one-var-declaration-per-line': 'error',
		'no-constructor-return': 'error',
		'no-console': 'off',
		'no-empty-function': 'warn',
		'no-eval': 'error',
		'no-extend-native': 'error',
		'no-extra-bind': 'error',
		'no-floating-decimal': 'error',
		'no-implicit-coercion': 'error',
		'no-implicit-globals': 'error',
		'no-implied-eval': 'error',
		'no-invalid-this': 'error',
		'no-labels': 'error',
		'no-lone-blocks': 'error',
		'no-new': 'error',
		'no-new-func': 'error',
		'no-new-wrappers': 'error',
		'no-octal-escape': 'error',
		'no-proto': 'error',
		'no-return-assign': 'warn',
		'no-script-url': 'error',
		'no-self-compare': 'warn',
		'no-sequences': 'warn',
		'no-throw-literal': 'error',
		'no-unmodified-loop-condition': 'error',
		'no-unused-expressions': 'warn',
		'no-useless-call': 'error',
		'no-useless-concat': 'error',
		'no-useless-return': 'warn',
		'prefer-promise-reject-errors': 'error',
		radix: 'error',
		'require-await': 'error',
		'wrap-iife': ['warn', 'inside'],
		'no-shadow': 'error',
		'no-array-constructor': 'error',
		'no-bitwise': 'off',
		'no-multi-assign': 'warn',
		'no-new-object': 'error',
		'no-useless-computed-key': 'warn',
		'no-useless-rename': 'warn',
		'no-var': 'error',
		'prefer-const': 'warn',
		'prefer-numeric-literals': 'warn',
		'prefer-object-spread': 'warn',
		'prefer-rest-params': 'warn',
		'prefer-spread': 'warn',
		'prefer-template': 'warn',

		// No massive files
		'max-lines': ['warn', { max: 500, skipBlankLines: true, skipComments: true }],
		'max-lines-per-function': ['warn', { max: 100, skipBlankLines: true, skipComments: true }],

		// Imports & exports
		'sort-imports': 'off',
		'import/no-duplicates': 'error',
		'import/order': 'off',
		'import/first': 'error',
		'import/newline-after-import': 'error',
		'simple-import-sort/imports': 'error',
		'simple-import-sort/exports': 'error',

		// Named or default is fine
		'import/prefer-default-export': 'off',
	},
};
